AnimationStateData class

Stores mix (crossfade) durations to be applied when {@link AnimationState} animations are changed.

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

clear() → void
Removes all mix durations.
getDefaultMix() → double
getMix(Animation from, Animation to) → double
Returns the mix duration to use when changing from the specified animation to the other, or the getDefaultMix if no mix duration has been set.
getMixByName(String fromName, String toName) → double
Returns the mix duration to use when changing from the specified animation to the other, or the getDefaultMix if no mix duration has been set.
getSkeletonData() → SkeletonData
The SkeletonData to look up animations when they are specified by name.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
setDefaultMix(double defaultMix) → void
setMix(Animation from, Animation to, double duration) → Future<void>
Sets the mix duration when changing from the specified animation to the other.
setMixByName(String fromName, String toName, double duration) → void
Sets a mix duration by animation name.
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited