Attachment<T extends Pointer<NativeType>> class abstract

The base class for all attachments.

Implementers

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

copy() → Attachment<Pointer<NativeType>>
Returns a copy of the attachment. Copied attachments need to be disposed manually when no longer in use via the dispose method.
dispose() → void
getName() → String
The attachment's name.
getType() → AttachmentType
The attachment's type.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited