BoneData class

Stores the setup pose for a Bone.

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

getColor() → Color
The Color of the bone as it was in Spine, or a default color if nonessential data was not exported. Bones are not usually rendered at runtime.
getIndex() → int
The index of the bone in Skeleton.getBones.
getLength() → double
The bone's length.
getName() → String
The name of the bone, which is unique across all bones in the skeleton.
getParent() → BoneData?
The parent bone or null if this is the root bone.
getRotation() → double
The local rotation in degrees.
getScaleX() → double
The local scaleX.
getScaleY() → double
The local scaleY.
getShearX() → double
The local shearX.
getShearY() → double
The local shearY.
getTransformMode() → TransformMode
The TransformMode for how parent world transforms affect this bone.
getX() → double
The local x translation.
getY() → double
The local y translation.
isSkinRequired() → bool
When true, Skeleton.updateWorldTransform only updates this bone if the Skeleton.getSkin contains this bone.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
setColor(double r, double g, double b, double a) → void
setIsSkinRequired(bool isSkinRequired) → void
setLength(double length) → void
setRotation(double rotation) → void
setScaleX(double scaleX) → void
setScaleY(double scaleY) → void
setShearX(double shearX) → void
setShearY(double shearY) → void
setTransformMode(TransformMode mode) → void
setX(double x) → void
setY(double y) → void
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited