ConstraintData<T extends Pointer<NativeType>> class

The base class for all constraint datas.

Implementers

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

getName() → String
The constraint's name, which is unique across all constraints in the skeleton of the same type.
getOrder() → int
The ordinal of this constraint for the order a skeleton's constraints will be applied by Skeleton.updateWorldTransform.
isSkinRequired() → bool
When true, Skeleton.updateWorldTransform only updates this constraint if the skin returned by Skeleton.getSkin contains this constraint.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
setIsSkinRequired(bool isSkinRequired) → void
setOrder(int order) → void
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited