DebugRenderer class

Renders debug information for a SkeletonDrawable, like bone locations, to a Canvas. See DebugRenderer.render.

Constructors

DebugRenderer()
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
render(SkeletonDrawable drawable, Canvas canvas, List<RenderCommand> commands) → void
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited