Event class

Stores the current pose values for an {@link Event}.

See AnimationStateListener, EventType.event, and Events in the Spine User Guide.

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

getBalance() → double
getData() → EventData
The events's setup pose data.
getFloatValue() → double
getIntValue() → int
getStringValue() → String
getTime() → double
The animation time this event was keyed.
getVolume() → double
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
setBalance(double balance) → void
setFloatValue(double value) → void
setIntValue(int value) → void
setStringValue(String value) → void
setVolume(double volume) → void
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited