EventData class

Stores the setup pose values for an Event.

See Events in the Spine User Guide.

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

getAudioPath() → String
getBalance() → double
getFloatValue() → double
getIntValue() → int
getName() → String
The name of the event, which is unique across all events in the skeleton.
getStringValue() → String
getVolume() → double
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
setBalance(double value) → void
setFloatValue(double value) → void
setIntValue(int value) → void
setStringValue(String value) → void
setVolume(double volume) → void
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited