PathConstraint class

Stores the current pose for a path constraint. A path constraint adjusts the rotation, translation, and scale of the constrained bones so they follow a PathAttachment.

See Path constraints in the Spine User Guide.

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

getBones() → List<Bone>
The bones that will be modified by this path constraint.
getMixRotate() → double
A percentage (0-1) that controls the mix between the constrained and unconstrained rotation.
getMixX() → double
A percentage (0-1) that controls the mix between the constrained and unconstrained translation X.
getMixY() → double
A percentage (0-1) that controls the mix between the constrained and unconstrained translation Y.
getOrder() → int
getPosition() → double
The position along the path.
getSpacing() → double
The spacing between bones.
getTarget() → Slot
The slot whose path attachment will be used to constrained the bones.
isActive() → bool
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
setIsActive(bool isActive) → void
setMixRotate(double mixRotate) → void
setMixX(double mixX) → void
setMixY(double mixY) → void
setPosition(double position) → void
setSpacing(double spacing) → void
setTarget(Slot target) → void
toString() → String
A string representation of this object.
inherited
update() → void
Applies the constraint to the constrained bones.

Operators

operator ==(Object other) → bool
The equality operator.
inherited