PathConstraintData class

Stores the setup pose for a PathConstraint.

See Path constraints in the Spine User Guide.

Inheritance

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

getBones() → List<BoneData>
The bones that will be modified by this path constraint.
getMixRotate() → double
A percentage (0-1) that controls the mix between the constrained and unconstrained rotation.
getMixX() → double
A percentage (0-1) that controls the mix between the constrained and unconstrained translation X.
getMixY() → double
A percentage (0-1) that controls the mix between the constrained and unconstrained translation Y.
getName() → String
The constraint's name, which is unique across all constraints in the skeleton of the same type.
inherited
getOffsetRotation() → double
An offset added to the constrained bone rotation.
getOrder() → int
The ordinal of this constraint for the order a skeleton's constraints will be applied by Skeleton.updateWorldTransform.
inherited
getPosition() → double
The position along the path.
getPositionMode() → PositionMode
The mode for positioning the first bone on the path.
getRotateMode() → RotateMode
The mode for adjusting the rotation of the bones.
getSpacing() → double
The spacing between bones.
getSpacingMode() → SpacingMode
The mode for positioning the bones after the first bone on the path.
getTarget() → SlotData
The slot whose path attachment will be used to constrained the bones.
isSkinRequired() → bool
When true, Skeleton.updateWorldTransform only updates this constraint if the skin returned by Skeleton.getSkin contains this constraint.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
setIsSkinRequired(bool isSkinRequired) → void
inherited
setMixRotate(double mixRotate) → void
setMixX(double mixX) → void
setMixY(double mixY) → void
setOffsetRotation(double offsetRotation) → void
setOrder(int order) → void
inherited
setPosition(double position) → void
setPositionMode(PositionMode positionMode) → void
setRotateMode(RotateMode rotateMode) → void
setSpacing(double spacing) → void
setSpacingMode(SpacingMode spacingMode) → void
setTarget(SlotData target) → void
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited