PointAttachment class

An attachment which is a single point and a rotation. This can be used to spawn projectiles, particles, etc. A bone can be used in similar ways, but a PointAttachment is slightly less expensive to compute and can be hidden, shown, and placed in a skin.

See Point Attachments in the Spine User Guide.

Inheritance

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

computeWorldPosition(Bone bone) → Vec2
computeWorldRotation(Bone bone) → double
copy() → Attachment<Pointer<NativeType>>
Returns a copy of the attachment. Copied attachments need to be disposed manually when no longer in use via the dispose method.
inherited
dispose() → void
inherited
getColor() → Color
The color of the point attachment as it was in Spine, or a default clor if nonessential data was not exported. Point attachments are not usually rendered at runtime.
getName() → String
The attachment's name.
inherited
getRotation() → double
getType() → AttachmentType
The attachment's type.
inherited
getX() → double
getY() → double
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
setColor(double r, double g, double b, double a) → void
setRotation(double rotation) → void
setX(double x) → void
setY(double y) → void
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited