RegionAttachment class

An attachment that displays a textured quadrilateral.

See Region attachments in the Spine User Guide.

Inheritance

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

computeWorldVertices(Slot slot) → List<double>
Transforms and returns the attachment's four vertices to world coordinates. If the attachment has a Sequence, the region may be changed.
copy() → Attachment<Pointer<NativeType>>
Returns a copy of the attachment. Copied attachments need to be disposed manually when no longer in use via the dispose method.
inherited
dispose() → void
inherited
getColor() → Color
getHeight() → double
The height of the region attachment in Spine.
getName() → String
The attachment's name.
inherited
getOffset() → Float32List
For each of the 4 vertices, a pair of x,y values that is the local position of the vertex.
getPath() → String
getRegion() → TextureRegion?
getRotation() → double
The local rotation.
getScaleX() → double
The local scaleX.
getScaleY() → double
The local scaleY.
getSequence() → Sequence?
getType() → AttachmentType
The attachment's type.
inherited
getUVs() → Float32List
getWidth() → double
The width of the region attachment in Spine.
getX() → double
The local x translation.
getY() → double
The local y translation.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
setColor(double r, double g, double b, double a) → void
setHeight(double height) → void
setRotation(double rotation) → void
setScaleX(double scaleX) → void
setScaleY(double scaleY) → void
setWidth(double width) → void
setX(double x) → void
setY(double y) → void
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited