RenderCommand class

Stores the vertices, indices, and atlas page index to be used for rendering one or more attachments of a Skeleton to a Canvas. See the implementation of SkeletonDrawable.renderToCanvas on how to use this data to render it to a Canvas.

Properties

atlasPageIndex ↔ int
latefinal
blendMode ↔ BlendMode
latefinal
colors ↔ Int32List
latefinal
hashCode → int
The hash code for this object.
no setterinherited
indices ↔ Uint16List
latefinal
positions ↔ Float32List
latefinal
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
uvs ↔ Float32List
latefinal
vertices ↔ Vertices
latefinal

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited