Sequence class

Stores a sequence of TextureRegion instances that will switched through when set on an attachment.

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

apply(Slot slot, Attachment<Pointer<NativeType>> attachment) → void
getDigits() → int
getId() → int
getPath(String basePath, int index) → String
getRegions() → List<TextureRegion>
getSetupIndex() → int
getStart() → int
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
setDigits(int digits) → void
setId(int id) → void
setSetupIndex(int setupIndex) → void
setStart(int start) → void
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited