Slot class

Stores a slot's current pose. Slots organize attachments for Skeleton.getDrawOrder purposes and provide a place to store state for an attachment. State cannot be stored in an attachment itself because attachments are stateless and may be shared across multiple skeletons.

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

getAttachment() → Attachment<Pointer<NativeType>>?
The current attachment for the slot, or null if the slot has no attachment.
getBone() → Bone
The bone this slot belongs to.
getColor() → Color
The color used to tint the slot's attachment. If hasDarkColor is true, this is used as the light color for two color tinting.
getDarkColor() → Color
The dark color used to tint the slot's attachment for two color tinting, if hasDarkColor is true. The dark color's alpha is not used.
getData() → SlotData
The slot's setup pose data.
getSequenceIndex() → int
The index of the texture region to display when the slot's attachment has a Sequence. -1 represents the Sequence.getSetupIndex.
getSkeleton() → Skeleton
The skeleton this slot belongs to.
hasDarkColor() → bool
Returns whether this slot has a dark color set for two color tinting.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
setAttachment(Attachment<Pointer<NativeType>>? attachment) → void
setColor(Color color) → void
setDarkColor(Color color) → void
setSequenceIndex(int sequenceIndex) → void
setToSetupPose() → void
Sets this slot to the setup pose.
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited