SlotData class

Stores the setup pose for a Slot.

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

getAttachmentName() → String
The name of the attachment that is visible for this slot in the setup pose, or null if no attachment is visible.
getBlendMode() → BlendMode
The BlendMode for drawing the slot's attachment.
getBoneData() → BoneData
The bone this slot belongs to.
getColor() → Color
The Color used to tint the slot's attachment. If hasDarkColor is true, this is used as the light color for two color tinting.
getDarkColor() → Color
The dark color used to tint the slot's attachment for two color tinting, if hasDarkColor is true. The dark color's alpha is not used.
getIndex() → int
The index of the slot in Skeleton.getSlots.
getName() → String
The name of the slot, which is unique across all slots in the skeleton.
hasDarkColor() → bool
Returns whether this slot has a dark color set for two color tinting.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
setAttachmentName(String attachmentName) → void
setBlendMode(BlendMode mode) → void
setColor(double r, double g, double b, double a) → void
setDarkColor(double r, double g, double b, double a) → void
setHasDarkColor(bool hasDarkColor) → void
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited