TextureRegion class

A region within a texture, given in normalized texture coordinates of the top left (getU, getV) and bottom left (getU2, getV2) corner of the region within the texture.

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

getDegrees() → int
getHeight() → int
getOffsetX() → double
getOffsetY() → double
getOriginalHeight() → int
getOriginalWidth() → int
getTexture() → Pointer<Void>
getU() → double
getU2() → double
getV() → double
getV2() → double
getWidth() → int
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
setDegrees(int degrees) → void
setHeight(int height) → void
setOffsetX(double offsetX) → void
setOffsetY(double offsetX) → void
setOriginalHeight(int originalHeight) → void
setOriginalWidth(int originalWidth) → void
setTexture(Pointer<Void> texture) → void
setU(double u) → void
setU2(double u2) → void
setV(double v) → void
setV2(double v2) → void
setWidth(int width) → void
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited