TransformConstraint class

Stores the current pose for a transform constraint. A transform constraint adjusts the world transform of the constrained bones to match that of the target bone.

See Transform constraints in the Spine User Guide.

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

getBones() → List<Bone>
The bones that will be modified by this transform constraint.
getData() → TransformConstraintData
The transform constraint's setup pose data.
getMixRotate() → double
A percentage (0-1) that controls the mix between the constrained and unconstrained rotation.
getMixScaleX() → double
A percentage (0-1) that controls the mix between the constrained and unconstrained scale X.
getMixScaleY() → double
A percentage (0-1) that controls the mix between the constrained and unconstrained scale X.
getMixShearY() → double
A percentage (0-1) that controls the mix between the constrained and unconstrained shear Y.
getMixX() → double
A percentage (0-1) that controls the mix between the constrained and unconstrained translation X.
getMixY() → double
A percentage (0-1) that controls the mix between the constrained and unconstrained translation Y.
getOrder() → int
getTarget() → Bone
The target bone whose world transform will be copied to the constrained bones.
isActive() → bool
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
setIsActive(bool isActive) → void
setMixRotate(double mixRotate) → void
setMixScaleX(double mixScaleX) → void
setMixScaleY(double mixScaleY) → void
setMixShearY(double mixShearY) → void
setMixX(double mixX) → void
setMixY(double mixY) → void
setTarget(Bone target) → void
toString() → String
A string representation of this object.
inherited
update() → void
Applies the constraint to the constrained bones.

Operators

operator ==(Object other) → bool
The equality operator.
inherited