TransformConstraintData class

Stores the setup pose for a {@link TransformConstraint}.

See Transform constraints in the Spine User Guide.

Inheritance

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

getBones() → List<BoneData>
The bones that will be modified by this transform constraint.
getMixRotate() → double
A percentage (0-1) that controls the mix between the constrained and unconstrained rotation.
getMixScaleX() → double
A percentage (0-1) that controls the mix between the constrained and unconstrained scale X.
getMixScaleY() → double
A percentage (0-1) that controls the mix between the constrained and unconstrained scale Y.
getMixShearY() → double
A percentage (0-1) that controls the mix between the constrained and unconstrained shear Y.
getMixX() → double
A percentage (0-1) that controls the mix between the constrained and unconstrained translation X.
getMixY() → double
A percentage (0-1) that controls the mix between the constrained and unconstrained translation Y.
getName() → String
The constraint's name, which is unique across all constraints in the skeleton of the same type.
inherited
getOffsetRotation() → double
An offset added to the constrained bone rotation.
getOffsetScaleX() → double
An offset added to the constrained bone scaleX.
getOffsetScaleY() → double
An offset added to the constrained bone scaleY.
getOffsetShearY() → double
An offset added to the constrained bone shearY.
getOffsetX() → double
An offset added to the constrained bone X translation.
getOffsetY() → double
An offset added to the constrained bone Y translation.
getOrder() → int
The ordinal of this constraint for the order a skeleton's constraints will be applied by Skeleton.updateWorldTransform.
inherited
getTarget() → BoneData
The target bone whose world transform will be copied to the constrained bones.
isLocal() → bool
isRelative() → bool
isSkinRequired() → bool
When true, Skeleton.updateWorldTransform only updates this constraint if the skin returned by Skeleton.getSkin contains this constraint.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
setIsLocal(bool isLocal) → void
setIsRelative(bool isRelative) → void
setIsSkinRequired(bool isSkinRequired) → void
inherited
setMixRotate(double mixRotate) → void
setMixScaleX(double mixScaleX) → void
setMixScaleY(double mixScaleY) → void
setMixShearY(double mixShearY) → void
setMixX(double mixX) → void
setMixY(double mixY) → void
setOffsetRotation(double offsetRotation) → void
setOffsetScaleX(double offsetScaleX) → void
setOffsetScaleY(double offsetScaleY) → void
setOffsetShearY(double offsetShearY) → void
setOffsetX(double offsetX) → void
setOffsetY(double offsetY) → void
An offset added to the constrained bone scaleX.
setOrder(int order) → void
inherited
setTarget(BoneData target) → void
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited