BoundsProvider class abstract

Base class for bounds providers. A bounds provider calculates the axis aligned bounding box used to scale and fit a skeleton inside the bounds of a SpineWidget.

Implementers

Constructors

BoundsProvider()
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

computeBounds(SkeletonDrawable drawable) → Bounds
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited