RawBounds class

A BoundsProvider that returns fixed bounds.

Inheritance

Constructors

RawBounds(double x, double y, double width, double height)

Properties

hashCode → int
The hash code for this object.
no setterinherited
height → double
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
width → double
final
x → double
final
y → double
final

Methods

computeBounds(SkeletonDrawable drawable) → Bounds
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited