SetupPoseBounds class

A BoundsProvider that calculates the bounding box of the skeleton based on the visible attachments in the setup pose.

Inheritance

Constructors

SetupPoseBounds()
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

computeBounds(SkeletonDrawable drawable) → Bounds
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited